==> ejc-assistrmat-impl-3.0.0-20220903.023609-167-sources.jar: com/ejianc/business/outrmat/settle/service/IOutRmatSettleService.java <==
package com.ejianc.business.outrmat.settle.service;

import com.ejianc.business.assist.rmat.vo.RentCalculateVO;
import com.ejianc.business.assist.rmat.vo.RestituteVO;
import com.ejianc.business.outrmat.lose.vo.OutRmatLoseVO;
import com.ejianc.business.outrmat.settle.bean.OutRmatSettleEntity;
import com.ejianc.business.outrmat.settle.vo.OutRmatSettleRecordVO;
import com.ejianc.business.outrmat.settle.vo.OutRmatSettleVO;
import com.ejianc.business.targetcost.vo.ExecutionVO;
import com.ejianc.framework.skeleton.template.IBaseService;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 周转材租赁结算单
 * 
 * @author generator
 * 
 */
public interface IOutRmatSettleService extends IBaseService<OutRmatSettleEntity> {

    OutRmatSettleVO saveOrUpdate(OutRmatSettleVO saveOrUpdateVO);
    
    String validateContract(Long contractId, Long billId);
//待修改
    List<RentCalculateVO> queryCalculateData(Long contractId, String lastSettleDate, String settleDate);
//待修改
    List<RestituteVO> queryRestituteData(Long contractId, String lastSettleDate, String settleDate);

    List<OutRmatLoseVO> queryLoseData(Long contractId, String lastSettleDate, String settleDate);

    OutRmatSettleVO queryLastSettleTaxMny(Long contractId, Long billId);

    OutRmatSettleRecordVO querySettleRecord(Long id);

    Boolean pushSettleToPool(OutRmatSettleVO vo);

    Boolean delSettleFromPool(Long id);

    ExecutionVO targetCost(OutRmatSettleEntity entity);

    Boolean pushContract(OutRmatSettleVO vo, String updateLevel);

    Boolean pushBillToSupCenter(OutRmatSettleEntity entity);

    Boolean delPushBill(OutRmatSettleEntity entity);

    String updateBillSupSignSyncInfo(HttpServletRequest request);
    
}

==> ejc-assistrmat-impl-3.0.0-20220909.014939-179-sources.jar: com/ejianc/business/outrmat/settle/service/IOutRmatSettleService.java <==
package com.ejianc.business.outrmat.settle.service;

import com.ejianc.business.assist.rmat.vo.RentCalculateVO;
import com.ejianc.business.assist.rmat.vo.RestituteVO;
import com.ejianc.business.outrmat.contract.vo.record.OutRmatContractSettleRecordVO;
import com.ejianc.business.outrmat.lose.vo.OutRmatLoseVO;
import com.ejianc.business.outrmat.restitute.vo.OutRmatRestituteVO;
import com.ejianc.business.outrmat.settle.bean.OutRmatSettleEntity;
import com.ejianc.business.outrmat.settle.vo.OutRmatSettleVO;
import com.ejianc.business.targetcost.vo.ExecutionVO;
import com.ejianc.framework.skeleton.template.IBaseService;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 周转材租赁结算单
 * 
 * @author generator
 * 
 */
public interface IOutRmatSettleService extends IBaseService<OutRmatSettleEntity> {

    OutRmatSettleVO saveOrUpdate(OutRmatSettleVO saveOrUpdateVO);
    
    String validateContract(Long contractId, Long billId);
//待修改
    List<RentCalculateVO> queryCalculateData(Long contractId, String lastSettleDate, String settleDate);
    List<OutRmatRestituteVO> queryRestituteData(Long contractId, String lastSettleDate, String settleDate);

    List<OutRmatLoseVO> queryLoseData(Long contractId, String lastSettleDate, String settleDate);

    OutRmatSettleVO queryLastSettleTaxMny(Long contractId, Long billId);

    OutRmatContractSettleRecordVO querySettleRecord(Long id);

    Boolean pushSettleToPool(OutRmatSettleVO vo);

    Boolean delSettleFromPool(Long id);

    ExecutionVO targetCost(OutRmatSettleEntity entity);

    Boolean pushContract(OutRmatSettleVO vo, String updateLevel);

    Boolean pushBillToSupCenter(OutRmatSettleEntity entity);

    Boolean delPushBill(OutRmatSettleEntity entity);

    String updateBillSupSignSyncInfo(HttpServletRequest request);
    
}
